.. py:module:: bcdi.xcca

.. toctree::
   :maxdepth: 2

:mod:`bcdi.xcca`: X-ray cross-correlation analysis
==================================================

xcca_utils
^^^^^^^^^^

This module provides methods to calculate the angular cross-correlation function for
a 3D reciprocal space dataset measured in forward CDI geometry.

API Reference
-------------

.. automodule:: bcdi.xcca.xcca_utils
   :members:
